<?php

namespace Drupal\invite\ParamConverter;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\ParamConverter\ParamConverterInterface;
use Drupal\invite\Entity\Invite;
use Symfony\Component\Routing\Route;

/**
 * Class InviteParamConverter.
 *
 * Class to convert parameters.
 */
class InviteParamConverter implements ParamConverterInterface {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs an object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Applies function.
   */
  public function applies($definition, $name, Route $route) {
    return (!empty($definition['type']) && $definition['type'] == 'reg_code');
  }

  /**
   * Converts reg_code to invite.
   */
  public function convert($reg_code, $definition, $name, array $defaults) {
    $invite = $this->entityTypeManager->getStorage('invite')->loadByProperties(['reg_code' => $reg_code]);
    return reset($invite);
  }

}
